@@ -1,5 +1,5 @@
 
-import struct, sets, time
+import struct, time
 
 from twisted.internet import protocol, defer, reactor
 from twisted.python.failure import Failure
@@ -167,7 +167,7 @@ class Banana(protocol.Protocol):
         self.openCount = 0
         self.outgoingVocabulary = {}
         self.nextAvailableOutgoingVocabularyIndex = 0
-        self.pendingVocabAdditions = sets.Set()
+        self.pendingVocabAdditions = set()
 
     def initSlicer(self):
         self.rootSlicer = self.slicerClass(self)
@@ -680,6 +680,15 @@ class Banana(protocol.Protocol):
                                   self.disconnectTimerFired)
             self.disconnectTimer = t
 
+    def getDataLastReceivedAt(self):
+        """If keepalives are enabled, this returns the seconds-since-epoch
+        when the most recent data was received on this connection. If
+        keepalives are disabled (which is the detault), it returns None."""
+
+        if self.useKeepalives:
+            return self.dataLastReceivedAt
+        return None
+
     def connectionTimedOut(self):
         # this is to be implemented by higher-level code. It ought to log a
         # suitable message and then drop the connection.
