@@ -28,6 +28,13 @@ class CLI(RequiresCryptoBase, unittest.TestCase):
         def _check((rc,out,err)):
             self.failUnlessEqual(rc, 0)
             self.failUnless(os.path.isdir(serverdir))
+            # check that the directory is group/world-inaccessible, even on
+            # windows where those concepts are pretty fuzzy. Do this by
+            # making sure the mode doesn't change when we chmod it again.
+            mode1 = os.stat(serverdir).st_mode
+            os.chmod(serverdir, 0700)
+            mode2 = os.stat(serverdir).st_mode
+            self.failUnlessEqual("%o" % mode1, "%o" % mode2)
         d.addCallback(_check)
         return d
 
@@ -49,7 +56,7 @@ class CLI(RequiresCryptoBase, unittest.TestCase):
         basedir = "appserver/CLI/create2"
         os.makedirs(basedir)
         serverdir = os.path.join(basedir, "fl")
-        d = self.run_cli("create", "--port", "tcp:0", serverdir)
+        d = self.run_cli("create", "--port","tcp:0", "--umask","022", serverdir)
         def _check((rc,out,err)):
             self.failUnlessEqual(rc, 0)
             self.failUnless(os.path.isdir(serverdir))
@@ -58,6 +65,8 @@ class CLI(RequiresCryptoBase, unittest.TestCase):
             portnum = int(got_port[got_port.find(":")+1:])
             prefix = open(os.path.join(serverdir, "furl_prefix"), "r").read().strip()
             self.failUnless(prefix.endswith(":%d/" % portnum), prefix)
+            umask = open(os.path.join(serverdir, "umask")).read().strip()
+            self.failUnlessEqual(umask, "0022")
         d.addCallback(_check)
         return d
 
